@@ -161,7 +161,7 @@ def create_meshing_tasks(
     mesh_dir=None, cdn_cache=False, dust_threshold=None,
     object_ids=None, progress=False, fill_missing=False,
     encoding='precomputed', spatial_index=True, sharded=False,
-    compress='gzip', closed_dataset_edges=True
+    compress='gzip', closed_dataset_edges=True, dust_global=False
   ):
   shape = Vec(*shape)
 
@@ -199,6 +199,7 @@ def create_meshing_tasks(
         mesh_dir=mesh_dir, 
         cache_control=('' if cdn_cache else 'no-cache'),
         dust_threshold=dust_threshold,
+        dust_global=bool(dust_global),
         progress=progress,
         object_ids=object_ids,
         fill_missing=fill_missing,
@@ -228,6 +229,7 @@ def create_meshing_tasks(
           'sharded': sharded,
           'compress': compress,
           'closed_dataset_edges': closed_dataset_edges,
+          'dust_global': bool(dust_global),
         },
         'by': operator_contact(),
         'date': strftime('%Y-%m-%d %H:%M %Z'),
@@ -446,6 +448,8 @@ def configure_multires_info(
       cache_control="no-cache"
     )
 
+  return new_mesh_info
+
 def create_unsharded_multires_mesh_tasks(
   cloudpath:str, num_lod:int = 0, 
   magnitude:int = 3, mesh_dir:str = None,
@@ -685,7 +689,7 @@ def create_sharded_multires_mesh_tasks(
   max_labels_per_shard:Optional[int] = None,
 ) -> Iterator[MultiResShardedMeshMergeTask]: 
 
-  configure_multires_info(
+  mesh_info = configure_multires_info(
     cloudpath, 
     vertex_quantization_bits, 
     mesh_dir
@@ -720,6 +724,7 @@ def create_sharded_multires_mesh_tasks(
     data_encoding="raw", # draco encoded meshes
   )
 
+  cv.mesh.meta.info = mesh_info # ensure no race conditions
   cv.mesh.meta.info['sharding'] = spec.to_dict()
   cv.mesh.meta.commit_info()
 
