@@ -575,14 +575,17 @@ def ImageShardDownsampleTask(
   shape_bbox = Bbox(upper_offset, upper_offset + shard_shape)
   shape_bbox = shape_bbox.astype(np.int64)
   shape_bbox = Bbox.clamp(shape_bbox, src_vol.meta.bounds(mip + 1))
-  shape_bbox = shape_bbox.expand_to_chunk_size(src_vol.meta.chunk_size(mip + 1))
+  shape_bbox = shape_bbox.expand_to_chunk_size(
+    src_vol.meta.chunk_size(mip + 1), 
+    offset=src_vol.meta.voxel_offset(mip + 1)
+  )
 
   if shape_bbox.subvoxel():
     return
 
   shard_shape = list(shape_bbox.size3()) + [ 1 ]
 
-  output_img = np.zeros(shard_shape, dtype=src_vol.dtype)
+  output_img = np.zeros(shard_shape, dtype=src_vol.dtype, order="F")
   nz = int(math.ceil(bbox.dz / chunk_size.z))
 
   dsfn = tinybrain.downsample_with_averaging
@@ -598,7 +601,10 @@ def ImageShardDownsampleTask(
     (ds_img,) = dsfn(img, factor, num_mips=1, sparse=sparse)
     # ds_img[slc] b/c sometimes the size round up in tinybrain
     # makes this too large by one voxel on an axis
-    output_img[:,:,(z*chunk_size.z):(z+1)*chunk_size.z] = ds_img
+    xlim, ylim = tuple(ds_img.shape[:2])
+    zs = z * chunk_size.z
+    ze = (z+1) * chunk_size.z
+    output_img[:xlim,:ylim,zs:ze] = ds_img
 
     del img
     del ds_img
